==> 1.0.3.tar.gz: lib/extension/source/rx.dart <==
import 'dart:async' as Async;

import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:getx_extended/export.dart';
import 'package:getx_extended/widget/export.dart';
import 'package:rxdart/rxdart.dart' as Reactive;

extension GetExtension<T> on Rx<T> {
  ObxValue<Rx<T>> toWidget(
    Widget Function(Rx<T> rx) builder,
  ) =>
      ObxValue<Rx<T>>(builder, this);
}

extension GetExtensionX<T> on RxPageable<T> {
  ObxValue<RxPageable<T>> toWidget(
    Widget Function(RxPageable<T> rx) builder,
  ) =>
      ObxValue<RxPageable<T>>(builder, this);
}

extension RxBoolX on RxBool {
  ObxValue<RxBool> toBlockingWidget(
    Widget Function(RxBool rx) builder,
  ) =>
      ObxValue<RxBool>(
        (rx) => Opacity(
          opacity: rx.value ? 0.3 : 1,
          child: builder(rx),
        ),
        this,
      );
}

extension GetReactiveExtension<T> on Rx<T> {
  Async.StreamSubscription<T> listenWithInitialValue(
          void Function(T data) onData) =>
      initialValueStream().listen(onData);

  Async.Stream<T> initialValueStream() =>
      Future.value(value).toStream().mergeWith([
        subject.stream.asBroadcastStream(),
      ]);
}

extension RxPageableX<T> on RxPageable<T> {
  AutoFetchList<T> toAutoFetchList({
    required Widget Function(T item) builder,
    bool reverse = false,
    bool shrinkWrap = false,
    Widget? header,
    Widget? separator,
    Widget? empty,
    EdgeInsetsGeometry? padding,
    VoidCallback? next,
  }) =>
      AutoFetchList<T>(
        builder: builder,
        source: this,
        reverse: reverse,
        shrinkWrap: shrinkWrap,
        header: header,
        separator: separator,
        empty: empty,
        padding: padding,
        next: next,
      );
}

==> 1.1.1.tar.gz: lib/extension/source/rx.dart <==
import 'dart:async' as Async;

import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:getx_extended/export.dart';
import 'package:getx_extended/widget/export.dart';
import 'package:rxdart/rxdart.dart' as Reactive;

extension GetExtension<T> on Rx<T> {
  ObxValue<Rx<T>> toWidget(
    Widget Function(Rx<T> rx) builder,
  ) =>
      ObxValue<Rx<T>>(builder, this);
}

extension GetExtensionX<T> on RxPageable<T> {
  ObxValue<RxPageable<T>> toWidget(
    Widget Function(RxPageable<T> rx) builder,
  ) =>
      ObxValue<RxPageable<T>>(builder, this);
}

extension RxBoolX on RxBool {
  ObxValue<RxBool> toOpacityWidget(
    Widget Function(RxBool rx) builder,
  ) =>
      ObxValue<RxBool>(
        (rx) => Opacity(
          opacity: rx.value ? 0.3 : 1,
          child: builder(rx),
        ),
        this,
      );
}

extension GetReactiveExtension<T> on Rx<T> {
  Async.StreamSubscription<T> listenWithInitialValue(
    void Function(T data) onData,
  ) =>
      initialValueStream().listen(onData);

  Async.Stream<T> initialValueStream() => subject.stream
      .asBroadcastStream()
      .mergeWith([Future.value(value).toStream()]);
}

extension RxPageableX<T> on RxPageable<T> {
  RxPageableList<T> toAutoFetchList({
    required Widget Function(T item) builder,
    bool reverse = false,
    bool shrinkWrap = false,
    Widget? header,
    Widget? separator,
    Widget? empty,
    EdgeInsetsGeometry? padding,
    VoidCallback? next,
  }) =>
      RxPageableList<T>(
        builder: builder,
        source: this,
        reverse: reverse,
        shrinkWrap: shrinkWrap,
        header: header,
        separator: separator,
        empty: empty,
        padding: padding,
        next: next,
      );
}
